@@ -19,7 +19,7 @@ list in your `buildozer.spec` file.
 help behaviour mixin
 --------------------
 
-The mixin class :class:`HelpBehaviour`
+The mixin class :class:`HelpBehavior`
 of this namespace portion is extending
 and preparing any Kivy widget for to
 show an individual help text for it.
@@ -33,7 +33,7 @@ show an individual help text for it.
 
 The correct identification of each
 help-aware widget presuppose that the
-attribute :attr:`~HelpBehaviour.help_id`
+attribute :attr:`~HelpBehavior.help_id`
 has a unique value for each widget
 instance. This is done automatically for
 the widgets provided by the
@@ -41,7 +41,7 @@ module :mod:`~ae.kivy_app` for to change
 the app flow or app states (like e.g.
 :class:`~ae.kivy_app.FlowButton`).
 
-The :attr:`~HelpBehaviour.help_vars`
+The :attr:`~HelpBehavior.help_vars`
 is a dict which can be used to provide extra
 context data for the generation and the
 display of help texts.
@@ -90,9 +90,10 @@ from kivy.app import App
 
 from ae.core import main_app_instance                                                       # type: ignore
 from ae.gui_help import HelpAppBase                                                         # type: ignore
+from ae.kivy_relief_canvas import ReliefCanvas                                              # type: ignore
 
 
-__version__ = '0.1.6'
+__version__ = '0.1.9'
 
 
 Builder.load_string("""\
@@ -102,7 +103,7 @@ Builder.load_string("""\
 #: import layout_ps_hints ae.gui_help.layout_ps_hints
 
 
-<HelpBehaviour>:
+<HelpBehavior>:
     help_id: ''
     # 'help_layout is not None' is needed because None is not allowed for bool help_lock attribute/property
     help_lock: app.help_layout is not None and app.displayed_help_id != self.help_id
@@ -111,13 +112,13 @@ Builder.load_string("""\
         Color:
             rgba: app.font_color[:3] + (0.24 if self.help_lock else 0, )
         Ellipse:
-            pos: self.x + dp(9), self.y + dp(9)
-            size: self.width - dp(18), self.height - dp(18)
+            pos: self.x + sp(9), self.y + sp(9)
+            size: self.width - sp(18), self.height - sp(18)
         Color:
             rgba: app.font_color[:3] + (0.51 if self.help_lock else 0, )
         Line:
             width: sp(3)
-            rounded_rectangle: self.x + dp(3), self.y + dp(3), self.width - dp(6), self.height - dp(6), sp(15)
+            rounded_rectangle: self.x + sp(3), self.y + sp(3), self.width - sp(6), self.height - sp(6), sp(12)
 
 
 <HelpLayout>:
@@ -138,8 +139,8 @@ Builder.load_string("""\
         Color:
             rgba: app.font_color[:3] + (root.ani_value, )
         Line:
-            width: dp(3)
-            rounded_rectangle: root.x + dp(1), root.y + dp(1), root.width - dp(2), root.height - dp(2), dp(12)
+            width: sp(3)
+            rounded_rectangle: root.x + sp(1), root.y + sp(1), root.width - sp(2), root.height - sp(2), sp(12)
         Triangle:
             points:
                 anchor_points(app.main_app.font_size * 0.69, root.ps_hints['anchor_x'], root.ps_hints['anchor_y'], \
@@ -147,8 +148,8 @@ Builder.load_string("""\
         Color:
             rgba: Window.clearcolor[:3] + (root.ani_value, )
         Line:
-            width: dp(1)
-            rounded_rectangle: root.x + dp(1), root.y + dp(1), root.width - dp(2), root.height - dp(2), dp(12)
+            width: sp(1)
+            rounded_rectangle: root.x + sp(1), root.y + sp(1), root.width - sp(2), root.height - sp(2), sp(12)
     Label:
         id: help_label
         text: root.help_text
@@ -156,7 +157,7 @@ Builder.load_string("""\
         background_color: Window.clearcolor[:3] + (root.ani_value, )
         font_size: app.main_app.font_size * 0.81
         markup: True
-        padding: dp(12), dp(9)
+        padding: sp(12), sp(9)
         size_hint: None, None
         size: self.texture_size
 
@@ -167,7 +168,7 @@ Builder.load_string("""\
     size_hint_x: None
     width: self.height
     source: app.main_app.img_file(self.icon_name, app.app_states['font_size'], app.app_states['light_theme'])
-    canvas.after:
+    canvas.before:
         Color:
             rgba: min(self.ani_value * 1.5, 1), min(self.ani_value * 1.5, 1), 1 - self.ani_value, 1 - self.ani_value / 2
         Ellipse:
@@ -178,7 +179,7 @@ Builder.load_string("""\
 """)
 
 
-class HelpBehaviour(Widget):
+class HelpBehavior(Widget):
     """ behaviour mixin class for widgets having help texts. """
     help_id = StringProperty()      #: unique help id of the widget
     help_lock = BooleanProperty()   #: True if the help mode is active and this widget is not the help target
@@ -272,7 +273,7 @@ class HelpLayout(ScrollView):
             main_app.help_display('', dict())
 
 
-class HelpToggler(Image):                                                               # pragma: no cover
+class HelpToggler(ReliefCanvas, Image):                                                               # pragma: no cover
     """ widget for to activate and deactivate the help mode.
 
     For to prevent the dismiss of opened popups and dropdowns at help mode activation, this singleton instance has to:
